**free

//---<CREATE_OBJECTS>--------------------------------------------------------------------------------------------------------------------------------
//
//    @compile{
//             CRTRPGMOD MODULE(&O/&N)
//                       SRCFILE(&L/&F)
//                       SRCMBR(&N)
//                       OPTION(*EVENTF)
//                       DBGVIEW(*SOURCE)
//                       REPLACE(*YES)
//           }
//
//
//    <! nur bei automatischer Binder-Source Generierung          !>
//    <! Befehl GENBNDSRC kann auch Stand-alone ausgefhrt werden !>
//
//    @generate{
//              GENBNDSRC SRCLIB(&L)
//                        SRCFILE(&F)
//                        SRCMBR(&N)
//                        PGMLVL(*CURRENT)
//                        SIG(EPOSGMBH_1.0.0.0)
//                         <! 1234567890123456 !>
//             }
//
//    @create{
//              CRTSRVPGM SRVPGM(&O/&N)
//                        MODULE(&O/&N)
//                        SRCFILE(QSRVSRC)
//                        ACTGRP(*CALLER)
//                        BNDSRVPGM(
//                                    (QSYSDIR/QAXIS10CC)
//                                 )
//                        REPLACE(*YES)
//           }
//
//---</CREATE_OBJECTS>-------------------------------------------------------------------------------------------------------------------------------

//---------------------------------------------------------------------------------------------------------------------------------------------------
//
//  @name    HTTP
//
//  @purose  AXIS Wrapper Prozeduren
//
//  @author  Klaus-Peter Luttkus
//
//  @version 1.0.0 - 2020-05-06
//
//---------------------------------------------------------------------------------------------------------------------------------------------------


ctl-opt nomain;

ctl-opt alwnull(*usrctl);
ctl-opt option(*nodebugio:*srcstmt:*nounref);

/include /QIBM/ProdData/OS/WebServices/V1/client/include/Axis.rpgleinc

/include QPOW3RSRC,HTTP_H
/include QPOW3RSRC,HTTP_C



dcl-s gblURI like(tmplURI) inz;

dcl-s gblRequest like(tmplHTTPBuffer) inz;
dcl-s gblResponse like(tmplHTTPBuffer) inz;




dcl-proc createTransport export;
  dcl-pi *n ind;
      inEndPoint like(tmplURI) const;
      outHandle like(tmplHandle);
  end-pi;

  dcl-s retCode ind inz(*on);

  monitor;
   gblURI = inEndPoint;
   outHandle = axiscTransportCreate(%trim(gblURI):AXISC_PROTOCOL_HTTP11);
   if (outHandle = *NULL);
      retCode = *off;
   endif;
  on-error;
     retCode = *off;
  endmon;

  return retCode;

end-proc;


dcl-proc setHTTPMethod  export;
  dcl-pi *n ind;
      inHandle like(tmplHandle) const;
      inMethod char(7) const;
  end-pi;

  dcl-s lclProperties char(100);
  dcl-s lclContentType    char(100);
  dcl-s lclHeader        char(100);

  dcl-s retCode ind inz(*on);

  lclProperties = %trim(inMethod) + NULL_TERM;

  monitor;
     axiscTransportSetProperty(inHandle: AXISC_PROPERTY_HTTP_METHOD: %addr(lclProperties));
  on-error;
     retCode = *off;
  endmon;

  return retCode;

end-proc;


dcl-proc sendRequest  export;
  dcl-pi *n ind;
      inHandle like(tmplHandle) const;
      inRequest like(tmplHTTPBuffer) const;
  end-pi;

  dcl-s lclStatus int(10) inz;
  dcl-s retCode ind inz(*on);

  monitor;
   gblRequest = inRequest;
   lclStatus = axiscTransportSend(inHandle: %ADDR(gblRequest): %len(%trim(gblRequest)) : 0);
   if (lclStatus = -1);
      retCode = *off;
   else;
      lclStatus = axiscTransportFlush(inHandle);
         if (lclStatus = -1);
             retCode = *off;
         endif;
   endif;
  on-error;
     retCode = *off;
  endmon;

  return retCode;

end-proc;


dcl-proc getResponse  export;
  dcl-pi *n ind;
      inHandle like(tmplHandle) const;
      outResponse like(tmplHTTPBuffer);
  end-pi;

  dcl-s lclStatus int(10) inz;
  dcl-s retCode ind inz(*on);

  monitor;
     lclStatus = axiscTransportReceive(inHandle: %ADDR(gblResponse): %SIZE(gblResponse): 0);
     if (lclStatus = 0);
        retCode = *off;
     endif;
     outResponse = gblResponse;
  on-error;
     retCode = *off;
  endmon;

  return retCode;

end-proc;

dcl-proc setLogging  export;
  dcl-pi *n ind;
     inLogStatus ind const;
     inLogPath char(255) const;
  end-pi;

  dcl-s retCode ind inz(*on);

  monitor;
     if inLogStatus;
        axiscAxisStartTrace(%trim(inLogPath): *NULL);
     endif;
  on-error;
     retCode = *off;
  endmon;

  return retCode;

end-proc;


dcl-proc setSSLProperties;
  dcl-pi *n ind;
      inHandle like(tmplHandle) const;
  end-pi;

  dcl-s SSLCert         char(100);
  dcl-s SSLPassword     char(100);
  dcl-s NullStr         char(1) inz(NULL_TERM);
  dcl-s None            char(5);

  dcl-s retCode ind inz(*on);

  monitor;
     // Set SSL information - turn off SSLv2 and sslv3.
       NONE = 'NONE' + NULL_TERM;
       SSLPassword = 'changeit'+ NULL_TERM;
       SSLCert = '/qopensys/QIBM/ProdData/JavaVM/jdk60/32bit/jre/lib/security/cacerts' + NULL_TERM;
       axiscTransportSetProperty(inHandle: AXISC_PROPERTY_HTTP_SSL:
                                      %addr(SSLCert):
                                      %addr(SSLPassword):
                                      %addr(NULLSTR):
                                      %addr(NONE):
                                      %addr(NONE));
  on-error;
     retCode = *off;
  endmon;

  return retCode;
end-proc;


dcl-proc setHTTPBasicAuthentication;
  dcl-pi *n ind;
      inHandle like(tmplHandle) const;
      inUser like(tmplProperties) const;
      inPassword like(tmplProperties) const;
  end-pi;

  dcl-s lclUser varchar(100);
  dcl-s lclPassword varchar(100);

  dcl-s rc int(10) inz;

  dcl-s retCode ind inz(*on);

  monitor;
     lclUser = %trim(inUser) + NULL_TERM;
     lclPassword = %trim(inPassword) + NULL_TERM;
     rc = axiscTransportSetProperty(inHandle:AXISC_PROPERTY_HTTP_BASICAUTH:%addr(lclUser:*data): %addr(lclPassword:*data));
  on-error;
     retCode = *off;
  endmon;

  return retCode;

end-proc;


dcl-proc destroyService  export;
  dcl-pi *n ind;
      inHandle like(tmplHandle) const;
  end-pi;

  dcl-s retCode ind inz(*on);


  monitor;
     axiscTransportDestroy(inHandle);
  on-error;
     retCode = *off;
  endmon;

  return retCode;

end-proc;


